@@ -55,7 +55,7 @@ def postfix_sasl(settings, args):
     temp_dict = process_mail.process_mail(dict_general, temp_set, settings)
 
     # Results
-    report_text = ""
+    report_text = []
     if len(temp_dict) > 0:
         for email in temp_dict.keys():
 
@@ -63,12 +63,13 @@ def postfix_sasl(settings, args):
             if args.exec:
                 exec_cmd.external_exec(args.exec.name, email)
 
-            report_text += "\nE-mail address: {}\n".format(email)
-            for ip_auth in temp_dict[email]:
-                report_text += "\t{}\n".format(ip_auth)
+            temp_text = f"E-mail address: {email}\n"
+            for ip_info in temp_dict[email]:
+                temp_text += f"\t{ip_info}\n"
+            report_text.append(temp_text)
 
         # Report in screen
-        print(report_text)
+        print('\n'.join(report_text))
 
         if settings.smtp_enabled:
             report_mail.send_report_mail(report_text, settings)
@@ -112,7 +113,7 @@ def quota_high(settings, args):
 
     # Results
     email_quota_count = 0
-    report_text = "Email address(es) that hit quota limit (> {}):\n".format(args.quota_limit)
+    report_text = f"Email address(es) that hit quota limit (> {args.quota_limit}):\n"
 
     for email, quota_counter in dict_general.items():
 
@@ -121,7 +122,7 @@ def quota_high(settings, args):
         if quota_counter > int(args.quota_limit):
 
             if email not in settings.email_skip:
-                report_text += "  {} ({})\n".format(email, quota_counter)
+                report_text += f"  {email} ({quota_counter})\n"
                 email_quota_count += 1
 
                 # Execute external script when an anomaly is found for each e-mail
