@@ -1,6 +1,10 @@
 """Reports by email
 """
 
+# Workaround Python3.8 issue
+# https://github.com/marrow/mailer/issues/87
+import sys
+sys.modules["cgi.parse_qsl"] = None
 from marrow.mailer import Message, Mailer
 
 
@@ -14,6 +18,8 @@ def send_report_mail(plain_text, settings):
     Returns:
     """
 
+    report_text = '\n'.join(plain_text)
+
     mailer = Mailer({
         'manager.use': 'futures',
         'transport.use': 'smtp',
@@ -29,7 +35,7 @@ def send_report_mail(plain_text, settings):
 
     message = Message(author=settings.smtp_from, to=settings.smtp_to)
     message.subject = settings.smtp_subject
-    message.plain = plain_text
+    message.plain = report_text
 
     mailer.send(message)
     mailer.stop()
